==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/AverageTrueRangeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AverageTrueRangeIndicatorDescription } from "./AverageTrueRangeIndicatorDescription";
/**
 * @hidden
 */
var AverageTrueRangeIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AverageTrueRangeIndicatorDescriptionMetadata, _super);
    function AverageTrueRangeIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicatorDescriptionMetadata.b = function (a) {
        if (AverageTrueRangeIndicatorDescriptionMetadata.a == null) {
            AverageTrueRangeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AverageTrueRangeIndicatorDescriptionMetadata.c(AverageTrueRangeIndicatorDescriptionMetadata.a);
        }
        if (a.g(AverageTrueRangeIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(AverageTrueRangeIndicatorDescriptionMetadata.a);
    };
    AverageTrueRangeIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    AverageTrueRangeIndicatorDescriptionMetadata.d = function (a) {
        AverageTrueRangeIndicatorDescriptionMetadata.b(a);
        a.u("AverageTrueRangeIndicator", function () { return new AverageTrueRangeIndicatorDescription(); });
        a.t("AverageTrueRangeIndicator", AverageTrueRangeIndicatorDescriptionMetadata.a);
    };
    AverageTrueRangeIndicatorDescriptionMetadata.$t = markType(AverageTrueRangeIndicatorDescriptionMetadata, 'AverageTrueRangeIndicatorDescriptionMetadata');
    AverageTrueRangeIndicatorDescriptionMetadata.a = null;
    return AverageTrueRangeIndicatorDescriptionMetadata;
}(Base));
export { AverageTrueRangeIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AverageTrueRangeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AverageTrueRangeIndicatorDescription } from "./AverageTrueRangeIndicatorDescription";
/**
 * @hidden
 */
var AverageTrueRangeIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AverageTrueRangeIndicatorDescriptionMetadata, _super);
    function AverageTrueRangeIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AverageTrueRangeIndicatorDescriptionMetadata.b = function (a) {
        if (AverageTrueRangeIndicatorDescriptionMetadata.a == null) {
            AverageTrueRangeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AverageTrueRangeIndicatorDescriptionMetadata.c(AverageTrueRangeIndicatorDescriptionMetadata.a);
        }
        if (a.j(AverageTrueRangeIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(AverageTrueRangeIndicatorDescriptionMetadata.a);
    };
    AverageTrueRangeIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    AverageTrueRangeIndicatorDescriptionMetadata.d = function (a) {
        AverageTrueRangeIndicatorDescriptionMetadata.b(a);
        a.aa("AverageTrueRangeIndicator", function () { return new AverageTrueRangeIndicatorDescription(); });
        a.z("AverageTrueRangeIndicator", AverageTrueRangeIndicatorDescriptionMetadata.a);
    };
    AverageTrueRangeIndicatorDescriptionMetadata.$t = markType(AverageTrueRangeIndicatorDescriptionMetadata, 'AverageTrueRangeIndicatorDescriptionMetadata');
    AverageTrueRangeIndicatorDescriptionMetadata.a = null;
    return AverageTrueRangeIndicatorDescriptionMetadata;
}(Base));
export { AverageTrueRangeIndicatorDescriptionMetadata };
